// Voltages
const int minV = 5;          // minimum voltage to start walkman
const int maxV = 180;        // maximum output voltage to walkman
const int maxFan = 280;      // maximum input my fan can provide manually

// Pins
int fanPin = A1; 
int walkmanPin = 6;
int ledPins[5] = {8, 9, 10, 11, 12};

// Smoothing
const int numReadings = 6;
int readings[numReadings];      // the readings from the analog input
int index = 0;                  // the index of the current reading
int total = 0;                  // the running total
int average = 0;                // the average


void setup(){
  Serial.begin(9600); 

  // initial pin configuration
  pinMode(fanPin, INPUT);  
  pinMode(walkmanPin, OUTPUT);
  for( int i=0; i<5; i++ ) pinMode( ledPins[i], OUTPUT ); 

  // initialize all the readings to 0: 
  for (int thisReading = 0; thisReading < numReadings; thisReading++)
    readings[thisReading] = 0; 
}

void loop(){
  // Read fan current input
  int fanValue = smoothReading(analogRead( fanPin ));
  Serial.print( "Fan value smoothed: " );
  Serial.println( fanValue, DEC );

  // Translate to music speed
  int vel = map( fanValue, 0, maxFan, minV, maxV );
  if( vel <= (minV + 2) ) vel = 0;

  // Write speed to walkman
  analogWrite( walkmanPin, vel );
  Serial.print( "Music speed: " );
  Serial.println( vel );
  
  // Show speed through LEDs
  displaySpeed( vel );
}


// light LEDS to show music speed
void displaySpeed( int vel ){
  int lightAmount = map( vel, minV, maxV, 0, 1400 );

  Serial.print("Light amount: ");
  Serial.println(lightAmount);

  for( int i=0; i<5; i++ ){
    lightAmount -= 255;
    if( lightAmount > 0 ) digitalWrite( ledPins[i], HIGH );
    else  digitalWrite( ledPins[i], LOW );
  }
}

// function to smooth the readings from the fan
int smoothReading( int value ){
  // subtract the last reading and add the current one
  total= total - readings[index];           
  readings[index] = value; 

  // add the reading to the total and advance to the next pos in array
  total= total + readings[index];       
  index = index + 1;                    

  // if we're at the end of the array wrap around to the beginning: 
  if (index >= numReadings)  index = 0;                           

  // calculate the average:
  average = total / numReadings;         
  return average;
}




